/*
 * Gate.h
 * 
 * Copyright (C) 2008 Matthias Schiffer <matthias@gamezock.de>
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ZOOMEDIT_DATA_GATE_H_
#define ZOOMEDIT_DATA_GATE_H_

#include <list>
#include <libxml++/nodes/element.h>

namespace ZoomEdit {
namespace Data {

class Triangle;

class Gate {
  private:
    std::list<Triangle*> triangles;
    xmlpp::Element *gateNode;
    
    Glib::ustring id;
    Glib::ustring room1, room2;
    
    // Prevent shallow copy
    Gate(const Gate &o);
    Gate& operator=(const Gate &o);
    
  public:
    Gate(xmlpp::Element *node);
    virtual ~Gate();
    
    const std::list<Triangle*>& getTriangles() {
      return triangles;
    }
    
    Triangle* addTriangle();
    void removeTriangle(Triangle *t);
    
    const Glib::ustring& getId() const {
      return id;
    }
    
    void setId(const Glib::ustring &id0) {
      id = id0;
      gateNode->set_attribute("id", id0);
    }
    
    const Glib::ustring& getRoom1() const {
      return room1;
    }
    
    void setRoom1(const Glib::ustring &room) {
      room1 = room;
      gateNode->set_attribute("room1", room);
    }
    
    const Glib::ustring& getRoom2() const {
      return room2;
    }
    
    void setRoom2(const Glib::ustring &room) {
      room2 = room;
      gateNode->set_attribute("room2", room);
    }
    
    xmlpp::Element* getNode() const {
      return gateNode;
    }
};

}
}

#endif /*ZOOMEDIT_DATA_GATE_H_*/
