/*
 * Room.h
 * 
 * Copyright (C) 2008 Matthias Schiffer <matthias@gamezock.de>
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ZOOMEDIT_DATA_ROOM_H_
#define ZOOMEDIT_DATA_ROOM_H_

#include <list>
#include <libxml++/nodes/element.h>

namespace ZoomEdit {
namespace Data {

class Triangle;

class Room {
  private:
    std::list<Triangle*> triangles;
    xmlpp::Element *roomNode;
    
    std::list<Triangle*> floor;
    xmlpp::Element *floorNode;
    
    Glib::ustring id;
    
    void populateTriangle(xmlpp::Element *tNode);
    
    // Prevent shallow copy
    Room(const Room &o);
    Room& operator=(const Room &o);
    
  public:
    Room(xmlpp::Element *node);
    virtual ~Room();
    
    const std::list<Triangle*>& getTriangles() const {
      return triangles;
    }
    
    Triangle* addTriangle();
    void removeTriangle(Triangle *t);
    
    const std::list<Triangle*>& getFloorTriangles() const {
      return floor;
    }
    
    Triangle* addFloorTriangle();
    void removeFloorTriangle(Triangle *t);
    
    const Glib::ustring& getId() const {
      return id;
    }
    
    void setId(const Glib::ustring &id0) {
      id = id0;
      roomNode->set_attribute("id", id0);
    }
    
    xmlpp::Element* getNode() const {
      return roomNode;
    }
};

}
}

#endif /*ZOOMEDIT_DATA_ROOM_H_*/
