/*
 * Vector.cpp
 * 
 * Copyright (C) 2008 Matthias Schiffer <matthias@gamezock.de>
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "Vector.h"
#include <cmath>

namespace ZoomEdit {
namespace Data {

float Vector::lengthSq() const {
  return x*x + y*y + z*z;
}

float Vector::length() const {
  return std::sqrt(lengthSq());
}

Vector Vector::operator+(const Vector &v) const {
  return Vector(x + v.x, y + v.y, z + v.z);
}

Vector Vector::operator-(const Vector &v) const {
  return Vector(x - v.x, y - v.y, z - v.z);
}

float Vector::operator*(const Vector &v) const {
  return (x*v.x + y*v.y + z*v.z);
}

Vector Vector::operator*(float f) const {
  return Vector(x*f, y*f, z*f);
}

Vector Vector::operator/(float f) const {
  return Vector(x/f, y/f, z/f);
}

Vector Vector::operator%(const Vector &v) const {
  return Vector(y*v.z-z*v.y, z*v.x-x*v.z, x*v.y-y*v.x);
}

Vector& Vector::operator+=(const Vector &v) {
  x += v.x;
  y += v.y;
  z += v.z;
  
  return *this;
}

Vector& Vector::operator-=(const Vector &v) {
  x -= v.x;
  y -= v.y;
  z -= v.z;
  
  return *this;
}

Vector& Vector::operator*=(float f) {
  x *= f;
  y *= f;
  z *= f;
  
  return *this;
}

Vector& Vector::operator/=(float f) {
  x /= f;
  y /= f;
  z /= f;
  
  return *this;
}

Vector& Vector::operator%=(const Vector &v) {
  *this = *this % v;
  return *this;
}

}
}
