/*
 * Vertex.cpp
 * 
 * Copyright (C) 2008 Matthias Schiffer <matthias@gamezock.de>
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "Vertex.h"
#include <cmath>

namespace ZoomEdit {
namespace Data {

float Vertex::distanceSq(const Vertex &v) const {
  return (x - v.x)*(x - v.x) + (y - v.y)*(y - v.y) + (z - v.z)*(z - v.z);
}

float Vertex::distance(const Vertex &v) const {
  return std::sqrt(distanceSq(v));
}

Vector Vertex::operator-(const Vertex &v) const {
  return Vector(x - v.x, y - v.y, z - v.z);
}

Vertex Vertex::operator+(const Vector &v) const {
  return Vertex(x + v.getX(), y + v.getY(), z + v.getZ());
}

Vertex Vertex::operator-(const Vector &v) const {
  return Vertex(x - v.getX(), y - v.getY(), z - v.getZ());
}

Vertex& Vertex::operator+=(const Vector &v) {
  x += v.getX();
  y += v.getY();
  z += v.getZ();
  
  return *this;
}

Vertex& Vertex::operator-=(const Vector &v) {
  x -= v.getX();
  y -= v.getY();
  z -= v.getZ();
  
  return *this;
}

}
}
