/*
 * Vertex.h
 * 
 * Copyright (C) 2008 Matthias Schiffer <matthias@gamezock.de>
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ZOOMEDIT_DATA_VERTEX_H_
#define ZOOMEDIT_DATA_VERTEX_H_

#include "Vector.h"

namespace ZoomEdit {
namespace Data {

class Vertex {
  private:
    float x, y, z;
    
  public:
    Vertex() : x(0), y(0), z(0) {}
    Vertex(float x0, float y0, float z0) : x(x0), y(y0), z(z0) {}
    
    float getX() const {return x;}
    void setX(float x0) {x = x0;}
    
    float getY() const {return y;}
    void setY(float y0) {y = y0;}
    
    float getZ() const {return z;}
    void setZ(float z0) {z = z0;}
    
    float distanceSq(const Vertex &v) const;
    float distance(const Vertex &v) const;
    
    Vector operator-(const Vertex &v) const;
    
    Vertex operator+(const Vector &v) const;
    Vertex operator-(const Vector &v) const;
    
    Vertex& operator+=(const Vector &v);
    Vertex& operator-=(const Vector &v);
};

}
}

#endif /*ZOOMEDIT_DATA_VERTEX_H_*/
