/*
 * MapView.h
 * 
 * Copyright (C) 2008 Matthias Schiffer <matthias@gamezock.de>
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ZOOMEDIT_VIEW_MAPVIEW_H_
#define ZOOMEDIT_VIEW_MAPVIEW_H_

#include "View.h"
#include <sigc++/connection.h>

namespace ZoomEdit {

namespace Data {
class Level;
}

namespace View {

class TopView;

class MapView : public View {
  private:
    sigc::connection mainViewUpdate;
    
    float viewWidth, viewHeight;
    
    TopView *mainView;
    
    float scale, xCenter, yCenter;
    
    void getBounds(float *minX, float *maxX, float *minY, float *maxY);
    
  public:
    MapView(TopView *mainView0 = 0)
    : mainView(0), scale(1), xCenter(0), yCenter(0) {
      setMainView(mainView0);
    }
    
    TopView* getMainView() {return mainView;}
    void setMainView(TopView *mainView0);
    
    virtual void init();
    virtual void resize(float width, float height);
    
    virtual void render();
    
    virtual void zoom(int zoom, float, float);
    virtual void move(float x, float y, unsigned int state);
    virtual void click(float x, float y);
};

}
}

#endif /*ZOOMEDIT_VIEW_MAPVIEW_H_*/
